
# q-expansion of newform 6633.2.a.w, downloaded from the LMFDB on 09 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 6633
weight = 2
poly_data = [-2, -76, 810, -1418, -2655, 5665, 4055, -7180, -3042, 4406, 1186, -1472, -244, 272, 25, -26, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-3, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, -5, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-2955180, 52587574, 37177704, -236929666, -285346173, 255334209, 378647651, -129471301, -216429544, 36267818, 64184009, -5668067, -10291658, 452672, 843560, -13959, -27575], 2721286], [[7475216, -2741190, 61266470, -185771866, -343160673, 269048190, 341131425, -164353227, -119577953, 54021235, 9079495, -9676569, 3455495, 861143, -750284, -28638, 42559], 2721286], [[-14046846, 95399942, 120700328, -632034046, -259814761, 1009921700, 296216875, -713297661, -197099283, 265565835, 76456829, -54409075, -16740475, 5794521, 1897162, -250136, -86001], 5442572], [[1304566, -194899958, 766391708, 409017270, -3050589755, -971520000, 3484199211, 926415941, -1862883509, -409178781, 536270313, 91694179, -85202057, -10143163, 6997748, 439848, -230329], 5442572], [[4174317, 20978969, -152317469, -38093562, 500950147, 60356771, -590962892, -45126608, 348529496, 15446807, -114156154, -2362756, 21015197, 122103, -2027846, 1558, 79595], 1360643], [[-5537703, -94021995, 365681053, 308702831, -1291840014, -604682568, 1573370006, 529717833, -947234935, -225298893, 313985051, 48772765, -57932009, -5156829, 5547392, 210501, -214049], 1360643], [[11509244, -12167118, -509668620, 185598572, 2325621837, 247797786, -3061470609, -511831833, 1901012233, 280545071, -637884591, -67982097, 118167911, 7612317, -11322680, -320078, 436709], 2721286], [[3883726, 86395902, -418891184, -197113104, 1749423100, 357301761, -2459894649, -306121242, 1666914011, 118830016, -607800465, -20962052, 121251307, 1463506, -12411743, -17687, 508577], 2721286], [[-6108450, -319953262, 2081791976, 317934354, -7770480371, -1034666236, 9321614025, 1207166569, -5395277109, -582980099, 1704313463, 134712035, -299668645, -14797609, 27458058, 619284, -1019239], 5442572], [[-28578490, 81182342, 1251872764, -1245148378, -5639712377, 1497138648, 7652074093, -704397625, -4887347579, 169631241, 1678089323, -25410747, -317205775, 2650763, 31001512, -143736, -1221155], 5442572], [[-2067402, 243049590, -1637063940, -436321122, 7057365229, 1653756976, -9192528251, -1907216939, 5683448447, 927295873, -1895441525, -217587789, 347946495, 24351943, -32953894, -1040280, 1253765], 5442572], [[-4300557, 82377621, -457863913, -27896889, 1885868717, 123929547, -2405420675, -184975880, 1471128228, 96154703, -489405900, -22238925, 90310300, 2325772, -8656255, -87987, 335296], 1360643], [[4124632, 150091110, -1034876238, -48232968, 4177784523, 483143782, -5270944817, -669956011, 3183112315, 339135101, -1043075619, -79399203, 189253867, 8700073, -17814320, -359308, 676979], 2721286]]

hecke_ring_character_values = None
aps_data = [[0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0], [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, -1, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1], [-1, 0, 0, -1, -1, -1, 1, 1, 0, -1, -1, 1, 0, 0, 0, 0, -1], [1, 0, -1, -1, 0, 0, 1, 1, 1, 0, 0, 0, -1, 0, 0, 0, 1], [-1, 1, 0, 0, 0, 0, 0, 0, 0, -1, -1, 0, 0, 0, 0, 0, 0], [-1, 0, -1, -1, -1, -1, 2, 1, 1, 0, 0, 1, 0, 0, -1, 1, 0], [1, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 1, 0, 0, 0, 1, 0], [2, 0, -1, -1, 0, 0, 1, 1, 1, 0, -1, 1, -2, 0, 0, 0, -1], [2, 0, 1, 1, 2, 2, -2, -1, -1, 1, 0, 0, 0, 0, 0, -1, 1], [1, -1, -1, 1, 0, 0, 0, 0, 0, 1, -1, 0, 0, 0, 0, 0, 0], [-2, -2, -1, 1, 1, 2, -1, 1, 1, 2, 0, -1, 0, 0, -2, 1, 0], [0, 1, -1, -1, 0, 0, 0, 0, 0, 1, 0, 0, -1, 0, 1, 1, 1], [-1, 0, -1, -2, 0, -2, 2, 2, 2, 0, -1, 2, -1, 0, 1, -1, -1], [0, 0, -2, 1, 1, 1, -1, 0, 1, 2, 0, -1, -1, 0, -1, -1, 0], [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [1, -1, 1, 0, -1, 2, 0, 0, -1, 1, -1, 1, -1, 1, 0, 0, 0], [1, -1, 3, 1, -1, 1, -1, -1, 0, 0, 0, -1, 1, 0, -1, -1, -1], [2, -3, 1, 0, -2, 1, 0, 1, 1, 1, 2, 0, 1, 1, -1, 2, 1], [2, 2, 0, 1, 3, 1, 0, -1, -1, 0, -1, -1, -1, 0, 0, -1, 2], [2, 0, -2, 1, 1, 2, -2, 0, 0, 1, 0, 0, -1, 0, 0, 0, 2], [-2, -5, 0, 1, -4, 0, 0, 1, 2, 0, 1, 0, 2, 1, -2, 4, 0], [4, -4, -1, 0, -1, 2, 2, 0, -2, 0, 1, -1, 0, 2, 0, 2, 2], [6, 0, 2, 0, -3, 0, -1, -1, -2, -2, 2, -1, 0, 0, 0, -1, -1], [2, 0, -1, 0, 0, 0, 2, 0, 1, 0, 1, 0, 1, 1, -1, 2, 2], [1, 0, 1, 2, 2, 2, -1, -2, 0, 1, 0, 0, -1, 1, 0, 1, 2], [2, -1, 2, -1, 1, 0, 2, -1, -1, -2, 1, -1, 0, -2, 1, 0, 0], [3, -4, 0, 2, -4, 2, -4, 0, 0, 0, 1, 0, 2, 3, -3, 0, 0], [-1, 2, 1, -1, -1, -2, 0, 0, 0, 0, 0, -1, -1, -2, 1, 1, -1], [0, -3, 1, 0, -2, 2, -2, 0, -2, 1, 2, 0, 1, 2, 1, 0, 0], [-3, -1, 2, -2, -4, 1, 2, 2, 0, 0, 0, 2, 1, 0, -1, 2, -2], [1, -1, 1, 2, 1, -1, -2, 0, 0, 0, -1, -1, -1, -1, 0, -1, -1], [-3, -4, -1, 2, -2, 1, -2, 2, 5, 3, 2, 0, 1, 1, -2, 1, 0], [2, 5, 2, 0, 4, -1, 3, -1, -1, -1, -1, 1, 0, -2, 1, -3, 0], [-1, 3, -4, 0, 2, 0, 1, 1, 1, 1, 0, -2, -1, -1, -2, -1, 2], [-3, 4, -4, -1, 3, -1, 2, 1, 2, 0, -1, 1, -1, -3, 0, -1, 0], [3, 0, 0, 0, 1, 2, 1, -2, -2, -1, 0, -1, 0, 1, -2, 1, 1], [0, -6, 1, 2, -3, 4, -5, -1, 1, 1, 1, 0, 4, 1, -4, 2, 1], [0, 4, -3, 1, 2, -3, 2, 1, 2, 0, -3, 1, -2, 0, 1, -2, -1], [0, -1, 1, -2, 0, -1, 3, 1, 1, -1, -2, 1, -1, 0, 0, 1, 1], [1, 1, -3, -1, 0, 0, -1, 0, 2, 2, 1, 0, -2, 0, 1, -2, 2], [4, 0, 2, 4, 2, 1, -4, -1, -2, 2, -1, -2, 3, 0, 1, 0, 1], [5, -3, 0, 0, -2, 2, -2, 0, 0, 1, 0, -2, 2, 0, -2, 0, 1], [1, 0, 1, -2, -1, 2, 0, 0, -4, -2, 1, -5, 3, 0, -1, 2, 3], [0, 4, 1, 1, 0, -1, -1, 0, 2, 2, 1, 0, 0, 0, 1, -2, 0], [3, 0, -3, 1, 4, 1, 0, 2, 3, 3, 1, 0, -2, 1, -1, -1, 1], [-4, 1, -1, 0, 2, 1, 0, 3, 1, -1, -1, 0, 1, -1, -1, -1, 1], [3, -5, -2, 2, -1, 2, -3, 3, 2, 3, 1, -1, -1, 1, -2, 0, 0], [-1, -2, -4, -1, -1, -3, 3, 4, 5, 0, 1, 3, 2, 1, 0, 0, -1], [0, -2, 1, 3, -4, 0, -1, -1, -2, -2, -2, 0, 2, 1, 1, 1, 0], [-4, 0, -1, 0, -2, -4, 0, -1, 1, -1, -1, 1, 1, 0, 0, 2, -3], [1, -1, 2, 3, 1, 2, -5, -3, -1, 1, -1, 2, 0, 1, -1, 0, -1], [-3, -1, 1, 1, 0, -2, -1, 0, 1, 0, 1, 0, 5, -1, -1, 2, 1], [-5, -5, -2, -3, -5, -1, 0, 0, 1, 2, 2, 0, 2, 2, -4, 4, 2], [2, 7, -2, 0, -2, 0, 0, -1, -2, 0, -3, 0, -2, -1, 0, 0, -4], [0, -4, 1, 0, -4, -1, -1, 1, 1, -1, 1, 2, 0, 1, 1, -1, -3], [-1, 2, 1, 0, 1, 0, 3, -1, 3, 0, 1, -1, -1, -1, -2, 0, -1], [6, 1, -2, -4, 4, -1, 6, 2, 1, 0, 1, 2, -4, -1, 3, -2, 1], [-2, 2, -2, 1, -2, -1, -2, -1, 3, 2, -2, 0, 0, -3, 0, -2, -3], [0, 4, 3, 1, -1, -2, -2, -2, -1, -2, 0, 1, -2, -1, 1, -3, -5], [3, -4, 4, -3, -3, 1, 0, -1, -4, -2, 3, 0, -1, 3, 3, 1, 0], [1, -2, -1, 0, -6, -2, 0, 1, 1, -1, 0, 0, 4, 1, -4, 6, 1], [3, 3, -2, -1, 2, 1, 1, 2, -1, 0, -3, 3, -3, -1, 0, -4, -3], [-2, 2, -4, 0, 0, -1, 0, -1, -1, 0, -1, 1, -3, -4, 2, -1, -3], [-1, -1, 0, -1, -3, 0, -6, -1, -3, 0, 0, -3, 2, -1, 1, 2, 0], [-3, 0, -1, 1, -4, -2, -4, -3, -2, 1, 4, 0, 0, 1, 2, -1, 1], [6, -2, -2, 0, 2, 1, -2, -3, -5, 0, -1, 0, 0, 1, 0, 1, -1], [2, -4, 1, 1, 0, 3, 0, 0, 1, 1, 1, -2, 5, 4, -3, 6, 5], [5, -5, 4, 0, 2, 4, -1, -1, -2, -1, 1, -2, 0, 2, -1, 1, 0], [17, -4, -1, 1, 3, 0, 0, 1, 0, 1, -1, 1, -1, -2, 2, -2, 0], [-6, 1, 2, -2, -4, 1, -4, 0, -1, -2, -1, 0, 3, -2, 1, 2, -1], [-3, 5, -5, -4, -1, -4, 2, 4, 5, -3, -1, 0, 4, 0, -2, 4, 0], [-10, 1, 0, -4, -1, -3, 4, 1, -1, -2, 0, -2, 0, -5, 1, 1, 2], [2, 3, 1, 3, 1, 2, -7, -5, -3, 1, -4, -2, -3, -1, 0, -5, -2], [2, -1, -1, -1, -2, 3, -2, -3, -2, 2, 2, -1, 1, 0, -3, -2, 1], [3, -2, -6, 2, 6, 4, -3, 1, -1, 4, -2, -2, -3, 1, -2, -1, 0], [1, 0, 1, 4, 3, 3, -10, -4, -4, 3, -3, 1, 1, -1, 0, -3, -1], [-1, -4, -3, -5, -2, -1, 5, 4, 1, -4, 0, 0, 4, 0, -1, 5, 0], [-6, -1, -3, -6, 0, -4, 7, 3, 2, -2, 0, 3, -3, 2, 0, 0, -4], [4, -4, 6, 6, -2, 5, -10, -3, -5, 2, -2, 0, 3, 2, -2, -2, -1], [2, 4, 5, -2, 1, 0, 0, -1, 1, -1, 3, -1, 3, -4, 0, 1, 1], [-2, 1, 3, 2, -3, -1, -3, 1, 4, 2, -1, 1, 0, 2, -2, 1, -1], [-7, 1, 0, -3, -3, -2, 3, 1, 2, -2, -3, 0, 2, 1, 0, 1, 0], [4, -1, -2, 1, 0, 0, -1, -1, -3, 1, -2, -5, -1, -2, -3, -1, 1], [-6, 2, 1, 4, -2, -4, -2, -2, 0, -2, -3, 2, -1, -2, 1, -2, -7], [6, 2, 1, -4, -1, -1, 3, 2, 2, -2, 2, 1, 0, 1, 0, 2, 2], [5, -7, 0, 2, -2, 5, -4, 0, 2, 4, 2, -2, 3, 0, -1, 4, 2], [-10, 7, 0, -3, 3, -6, 10, 1, 3, -4, -3, 3, 0, -4, 3, 1, -1], [-4, 0, -4, -4, 1, -3, 11, 5, 3, -3, -1, 3, -3, -2, 1, -1, 0], [-5, 8, 0, 2, 6, -1, 1, -1, 2, -2, -3, -1, 0, -2, 1, 0, 1], [-1, -5, -4, 2, 1, 1, -1, -1, 5, 2, 2, 1, 4, 1, -3, 5, 0], [11, -1, -3, -2, -2, 3, 2, 0, -1, -1, 1, 1, 0, 1, 2, 0, 5], [-3, -1, -3, 1, -1, 3, -6, -1, 2, 5, 2, -1, -3, 0, -4, 0, -2], [2, 3, -1, 0, 2, 0, -1, -1, -4, -2, 1, 1, -1, 2, 2, -2, -1], [-1, 6, 0, -5, 0, -3, 4, 1, 1, -4, -3, 0, 1, -3, 3, -1, -2], [7, 1, 0, 2, 2, 5, -4, 0, 5, 6, 1, 2, -3, 3, 0, -1, 1], [-9, -4, 1, 1, -1, -1, 3, 2, 6, 2, 4, -5, 5, -2, -4, 4, 5], [-1, -5, -2, 1, -1, 1, -2, 2, 1, 0, 2, 3, -2, 5, -3, 1, -1], [2, 11, -3, -6, 2, -7, 6, 3, 4, -1, -3, 4, -2, -3, 4, -2, 1], [4, 1, -3, -4, 2, 3, 0, -3, -1, 3, -1, 0, -2, -3, -2, 0, 2], [1, 11, -2, 3, 5, 0, -2, -2, 1, 1, 3, 1, -3, -1, 0, -4, 2], [-4, 6, 0, -2, 0, -3, 4, 0, 5, -1, 0, 2, 2, 2, 0, 5, 1], [8, 0, -1, -2, 8, 5, 5, 1, 0, 5, 4, -4, -1, -1, 2, 2, 8], [-1, -1, -7, 0, 4, -2, 1, 5, 8, 7, 5, -1, -2, -2, -2, 3, 0], [15, -2, 6, -1, 3, 0, 2, 1, -5, -3, -3, 1, -4, 1, 4, -3, 0], [0, 4, -1, -1, -2, -3, 2, 1, 0, -3, 0, -3, 1, 0, -1, 4, 1], [8, -4, 1, -4, -8, 0, 3, 5, 0, 0, -1, 8, 1, 7, 0, 5, -1], [13, -2, 3, -1, -2, -3, 2, -2, -5, -5, 3, 0, 3, -1, -1, -3, -1], [4, -6, 4, 0, -3, 2, -2, 3, -2, -1, 4, 1, 1, 4, -2, 1, 1], [4, -6, 1, 0, -2, 4, 1, 5, 2, 4, 4, -3, 4, 4, -4, 6, 3], [1, -6, -1, 2, 10, 4, 1, 2, 2, 1, 5, -2, 0, 0, -3, -2, 6], [-9, -3, 0, -5, -7, -6, 8, 3, 4, -4, 3, -2, 6, 1, -4, 8, 0], [5, -9, 0, -5, -6, 2, 0, 3, 3, 4, 4, 0, 5, 1, -5, 5, 4], [1, -8, 2, 0, -4, 1, -5, 0, 3, 4, 6, 0, 3, 2, -4, 3, -2], [-1, -1, 5, 7, -1, 2, -7, -5, -5, 3, 3, -1, 0, 2, -2, -8, -3], [-5, 10, -2, 1, 7, -7, 4, 1, 4, -4, -3, -1, 0, -4, -1, -5, -2], [-1, 7, 6, -1, -2, 0, -3, -3, 1, -3, -3, 0, -3, -2, 2, -4, -2], [-1, -8, -3, 0, -3, -1, -1, -1, 2, -1, 1, 1, 3, 6, -1, 7, 4], [6, 0, -1, 1, 2, -1, -2, -1, 3, 4, 1, 4, -4, -2, -1, -3, -3], [4, -11, 2, 4, -14, 0, -5, 2, 3, 2, 0, 0, 4, 7, -7, 6, -3], [-3, 0, 1, -3, -11, -1, -4, 3, 5, -1, -1, 2, -1, 1, 0, 4, -5], [7, -4, 4, -3, 3, 4, -6, -1, -7, -1, -1, -3, 0, -4, 1, -1, 0], [0, -3, 3, 0, -10, 2, -8, -4, -4, 1, 0, 0, 5, -1, 1, -1, -1], [-1, 1, -3, -1, 2, -2, 3, 3, -2, -1, -6, 1, -1, -2, 3, -2, -2], [12, 6, 1, 0, 4, -4, 0, -4, -5, -2, -6, 4, -3, -2, 7, -4, -3], [8, -2, 5, 2, -4, -2, -8, -5, -8, -3, -4, -1, 3, -2, 2, -4, -5], [-1, -3, 1, -3, -7, 0, -3, -1, -2, -1, 4, 1, 2, 0, 0, 2, -1], [3, 3, 0, -4, 0, 5, 4, 0, -6, -2, -5, 6, -6, 0, 2, -4, -5], [6, 0, -1, 2, 8, 1, -3, 0, 6, 4, 6, -2, 1, 1, -1, -1, 4], [4, 2, -1, 2, 8, 0, 2, 0, 2, -2, -1, 0, -2, -4, 0, -4, 1], [0, -1, 2, -3, -2, 3, -2, 0, -2, 2, 2, 2, -2, -2, 0, 2, -1], [5, -6, 4, 7, 4, 8, -8, -3, -1, 5, 5, -2, 1, 5, -7, 1, 1], [-5, 3, 5, 0, 3, -1, 4, 0, -4, 0, -1, -5, -1, -4, 3, 0, 6], [-5, 6, 4, 4, 4, 0, -2, 1, 1, 1, 3, 2, -1, -1, -3, -5, -5], [4, 1, -2, -2, 4, -2, -2, -3, 1, -2, -2, 2, -1, -1, 1, -3, -3], [5, 4, -5, 0, -2, 0, 2, 4, 0, 3, -1, 3, -3, -1, 3, 1, 2], [10, 8, -2, 2, -2, -4, 5, 2, 3, 1, 0, 4, -3, 3, 5, 2, -1], [-6, -1, 2, 1, -7, 1, -7, -5, -4, -2, -4, 1, 3, 4, -1, 0, -5], [-4, 7, -7, 0, 5, -2, -1, -2, -5, -2, -4, -3, 1, -3, 3, 1, 1], [11, 1, 6, 5, 9, 2, -1, -3, -6, -1, -1, 1, -5, 0, 1, -1, 1], [0, 6, 6, 4, 3, 2, -2, -2, -2, -6, 0, -3, 5, -2, -3, 1, 0], [-1, -4, 4, 3, 2, -2, 0, 4, -2, 1, 2, 1, 2, 3, 2, -3, -5], [2, 0, -8, 1, 0, 3, -5, -1, 0, 3, -4, -2, 1, 3, 0, 4, 0], [0, -8, -2, 0, -5, 3, -2, 0, 0, 5, 2, 3, -4, 7, -1, -2, 0], [-1, 1, -3, -4, 4, -6, 5, 2, 7, 2, -1, 0, 1, 1, 1, 7, 0], [-13, -4, 4, -1, -6, -8, 2, 4, 7, -2, 1, 4, 5, 2, -1, 1, -8], [4, 5, 2, -3, -3, 1, -4, -3, -3, -1, -1, -1, 0, 2, 5, 0, 5], [-7, -3, 2, 0, -5, 3, -4, -3, -2, -3, 3, -5, 4, -4, -3, 1, 4], [2, 6, 5, 2, 9, 0, -9, -7, -10, -2, -1, -7, 4, -2, 4, -5, 2], [-4, 14, -5, 0, 5, -2, 3, 5, 6, 5, 1, -4, -3, -3, 1, 1, 3], [3, 9, 5, 2, 6, -1, 1, -1, 0, -4, 2, 0, -1, -1, 6, -4, 1], [7, -8, 0, -1, 0, 6, -3, 0, -1, 5, 2, 4, 2, 2, -1, 0, 0], [-10, -2, 3, 1, -2, -2, 1, -1, -3, -4, 0, 2, 8, 3, 1, 3, -1], [10, -2, 3, 2, -2, 3, -7, -9, -5, -1, 4, -6, 6, -1, -1, 0, 1], [-15, 0, 3, 1, 2, 4, -1, 2, 0, 1, 2, 0, 4, 0, -3, 3, 4], [-1, -3, 1, 4, -3, 3, -2, -3, -2, 3, 1, 3, -1, 5, 2, -3, -2], [3, -6, 7, 4, -1, 7, -6, -1, 5, 4, 0, -1, 1, -1, -3, 4, 1], [-3, 4, 1, 4, 7, -6, 2, 2, 3, -2, -3, 1, 2, 3, -1, 1, 1], [7, 6, 0, -5, 5, -7, 8, 2, -1, -5, -6, -1, -4, -7, 5, -6, -4], [8, 0, 1, -4, -7, -3, 6, 4, 3, -5, 4, 1, 6, -1, 1, 4, 1], [-2, -1, 1, 6, 1, 9, -2, 0, -2, 4, -4, -3, -1, 3, -6, 2, 4], [-2, 4, -5, -8, 1, -4, 7, 1, -2, -2, -3, 2, -2, -1, 1, 0, -3], [3, -13, 5, -5, -6, 4, -3, -3, -5, -1, 2, -1, 1, 4, -1, 6, 3], [4, -4, -4, -2, 2, 4, 4, 6, 7, 4, -2, -3, -4, 1, -3, 5, 4], [1, 0, -5, 0, -3, 0, 2, -1, 1, 1, -2, 1, 1, -2, -8, 3, 1], [7, 6, -2, 0, 8, 6, -2, -1, 7, 5, 0, 0, -3, -3, 1, -4, 3], [-4, -8, -2, -2, -3, -1, -1, 2, 2, 4, 11, 1, 1, 1, -3, 0, 3], [2, 5, -3, -7, 0, -1, 4, 2, -2, -4, 4, -4, 2, 1, -2, 2, 1], [-1, -6, 3, -2, 2, 2, -4, -3, -8, -4, 0, -5, 4, -4, 0, -3, -2], [4, -1, -5, 1, 1, 0, -4, 1, -5, 2, 2, -3, -2, -1, -1, 5, 0], [-10, 1, -5, -7, 3, -3, 7, 4, 4, -1, -4, 7, -3, 2, 3, 0, 0], [9, 2, -2, -3, -2, -2, -1, -1, -2, 0, 0, 1, 0, 0, -4, 3, -5], [-11, -5, -4, -3, -11, -5, 5, 5, 3, -4, -8, 3, 3, 0, -1, 2, -7], [-3, 2, -6, 1, 10, -3, 11, 6, 8, 2, -5, 8, -3, 0, 6, 0, 1], [-2, -1, 1, -4, 11, 0, 6, 5, 3, 2, 2, -1, 1, -2, 4, 1, 6], [20, 11, 3, -2, 10, -2, -3, -3, -7, -5, -4, 0, -4, -5, 5, -13, -5], [5, -6, 1, 0, 1, -2, 6, 2, 2, -4, 4, -3, 4, 3, -1, 11, 3], [12, -4, 3, 4, 0, -1, -4, -2, -7, -1, -4, -2, -3, -2, 7, -5, -5], [2, 4, 2, -3, 4, -1, -3, -4, -6, -2, 4, -2, 0, -1, 3, 1, 2], [9, -7, 2, -3, 0, -3, 3, -1, 0, -3, 3, -3, 1, 0, 4, 4, -1], [-7, 4, 0, -2, -9, -9, 8, 7, 4, -2, -5, 5, 0, 2, 3, 2, -3], [-8, -9, 3, -1, -5, 9, -7, -4, -1, 7, 5, 0, -2, 2, -3, -2, 4], [-7, -3, 6, 1, -6, -2, -5, -4, -9, -6, -1, 1, 9, -1, -1, 2, 1], [4, -13, 1, -6, -4, 6, -3, 1, -6, 1, 3, -2, 2, 4, 1, 7, 5], [-11, -2, -2, 1, -2, -2, -4, -3, 8, 4, 1, 1, 1, -2, -1, 1, 5], [-5, 11, -5, -1, 6, 0, -3, -1, 0, 3, -1, 0, -4, -1, 1, -10, -5], [1, -11, 2, 1, -5, 1, -7, -3, -2, 2, 2, 1, -4, 6, -2, -1, 1], [21, -5, -5, 2, 2, 3, 4, 3, 4, 3, 1, 5, -5, 6, -2, 2, -4], [0, 3, 3, 3, 5, 1, 0, -1, 0, 1, -2, 1, -1, -7, 3, -6, -3], [3, 7, 1, -5, -3, -2, 3, -1, -2, -3, 3, -1, -4, 2, 0, -1, 3], [0, 0, 1, 10, -2, 6, -9, -4, -5, 1, -1, -2, 3, 0, -2, -3, -1], [-5, -9, 7, -3, -9, 3, 4, -3, -7, -5, 4, -5, 5, 4, -2, 2, 5], [-14, 6, 1, 2, 0, -2, 6, 0, 4, 1, 1, 1, 2, -3, -2, 0, 2], [-3, -2, -2, 0, -3, -4, 4, 3, 3, 1, 3, -1, -2, -2, -1, 3, -2], [-1, 11, 5, -2, 2, -6, 9, 3, -3, -1, -2, 2, 1, -3, 4, -1, 2], [2, -12, 1, 1, -10, 10, -7, 0, -8, 3, 1, -6, 5, 3, -8, 8, 3], [-14, -3, 4, 1, -11, 3, 1, -3, -2, -4, -2, 5, 2, 5, -4, 2, -1], [4, 1, -14, -3, 1, -6, 10, 7, 12, 2, 7, 1, -5, 0, 0, -1, 4], [0, 2, -4, -4, -7, -6, -5, 0, 4, 1, 0, 1, 2, -3, 0, 1, -4], [15, 9, 0, 3, 12, 4, 1, -4, 4, 4, -1, 4, 1, 2, 4, -2, 2], [-10, -8, -1, -5, -13, 1, -6, -3, -6, -6, 2, -1, 8, 1, -6, 3, 0], [11, 3, -1, -5, 7, 1, 5, 5, -4, -3, -2, 2, -1, 1, 3, -3, 0], [-16, -4, 5, -1, -1, -1, 6, 3, -3, -2, -2, 4, 1, -1, -5, 2, -4], [2, -3, 0, -9, 1, -4, 9, 4, -2, -4, 0, -3, -3, -3, 3, 4, 1], [10, -16, 4, -1, -6, 6, -3, 2, 0, -1, -2, 6, 1, 8, -8, 7, -3], [-19, 2, -12, -4, -1, -7, 8, 12, 12, 3, 0, -1, -4, -5, -3, 2, 1], [-3, -13, 1, 1, -3, -1, 2, 9, 6, 1, -10, 4, 5, 3, -1, 4, -2], [-14, 7, 2, -6, -6, -7, 5, 1, 11, -4, 6, -2, 9, -3, -4, 4, -1], [2, 8, -1, 1, -2, 5, -3, -1, -3, 1, -2, -6, 4, -5, -5, 6, 5], [16, 7, -4, -3, 4, -3, 3, -1, -1, -6, -4, -7, 4, 0, 2, 4, 1], [-2, -6, 5, 14, 1, 10, -13, -8, -4, 9, 6, -1, -3, 1, 3, -8, 1], [-5, -7, 6, 0, -3, 1, 0, -2, -6, -2, 0, 5, 4, 3, 5, 1, 4], [-15, 7, 0, 9, 6, 0, -4, -1, 4, 4, 0, -4, 1, -7, -5, -8, -6], [3, 11, 1, -1, -2, -1, 4, -5, -2, -3, 1, -2, 0, -2, 1, -1, -1], [-7, 7, 1, -6, 6, -3, 7, -2, 0, -7, 3, 2, -1, 0, 2, 6, 5], [3, 5, -5, 1, 12, 2, -5, -5, -3, 5, -7, -1, -5, -4, 9, -5, 5], [-13, -4, 1, -9, -16, -4, 7, 6, -7, -8, -5, 7, 0, 3, 3, 2, -8], [-7, -8, -3, 9, 3, 1, -4, 2, 1, 5, 1, 3, -1, 5, -6, -1, -4], [8, 6, -10, -8, 5, -6, 6, 3, 0, -3, -3, 1, -6, -5, 9, -1, 0], [2, 7, -2, 0, -1, -6, 5, 6, 2, -2, -5, 5, -4, -3, 8, 3, -1], [-2, 6, 0, 2, 2, 1, 3, -1, 0, 5, 0, 0, -6, 1, -1, 2, 4], [8, -2, 0, 3, 0, -2, -6, -4, -1, -2, 0, 2, 6, 2, 0, 3, 2], [13, -8, 1, 0, 1, 2, 0, -2, -5, 0, -9, 7, -5, 5, 4, -3, -5], [-4, -5, 8, 0, -8, 0, -9, -6, -9, 0, -4, 5, 1, 3, -1, 3, -8], [-8, -3, -11, -5, -2, -1, 3, 6, 9, 9, 4, 1, -7, -1, -1, 0, 4], [1, -17, -3, -1, -6, 0, 8, 7, 6, 2, 10, 4, 1, 8, -3, 9, 3], [-27, -4, 1, 4, -4, -2, 2, 1, 15, 5, -2, 2, 2, -3, -4, 3, -4], [-6, -22, 1, -1, -17, 10, -7, -2, -7, -1, 6, -5, 13, 5, -11, 16, 4], [-13, -7, -4, -4, -13, 3, 1, 1, -3, -4, -5, 5, -1, 6, -1, 1, -7], [-12, -5, -2, -5, 3, -3, 12, 13, 5, 5, 0, 3, -4, 3, 3, 0, 2], [13, 3, -6, 7, 12, 0, -7, -6, -2, 0, -9, -4, 0, -7, 5, -7, 1], [5, -15, 3, 2, -5, 0, -4, -1, -1, -2, 7, -3, 10, 0, -3, 6, 1], [-8, -6, 2, 1, -7, -1, -3, 2, -3, -4, -6, -1, 4, -3, -2, 6, -1], [20, -9, -5, 9, 4, 11, -16, -2, -5, 8, -7, -3, -1, 5, -2, -3, 2], [0, 6, -6, 5, 7, -7, -4, -1, 3, 4, 5, -1, 3, -4, 4, -1, -4], [1, 4, -7, 0, -6, 0, -2, 2, 3, 2, -1, -2, 0, -4, -2, -1, 0], [14, -6, 3, 6, -1, 0, 1, 4, 1, 5, 11, -5, 0, 1, 0, 1, 2], [1, 10, -11, 0, 1, 1, 6, 7, 9, 8, -2, 5, -7, 0, -2, -6, -5], [-6, 4, -2, 2, -2, -5, 1, 4, 6, 2, -7, 0, 4, -4, -3, 9, 3], [4, 0, 1, 7, -3, 4, -10, -7, 3, 5, 2, 2, 1, -1, -9, -1, -6], [-2, 1, -5, -1, 9, 0, -2, -2, 8, 7, 0, -5, -3, -13, 0, 0, 3], [2, 3, 3, -5, 3, 0, 4, -5, -2, -4, -6, 1, -6, -3, 8, -7, -1], [4, 0, 2, -3, 6, 5, -1, 2, -4, 4, 13, -4, 0, -4, -1, 1, 3], [13, 17, -1, 2, 7, -5, -4, -4, -5, -6, -5, -3, -5, -7, 4, -9, -2], [18, 7, -3, 7, 10, 2, -2, -3, -9, 1, -12, 3, -9, 0, 7, -12, -3], [-2, 0, 0, -12, 10, -5, 10, -1, 1, -6, 1, -2, 2, -3, 0, 2, 2], [-19, -9, -2, -3, -6, 1, 6, 6, 4, 4, 3, 2, 8, 4, -2, 11, 0], [5, 7, 1, -2, 5, 2, 4, -1, 4, 2, 7, -1, 0, -2, -3, -2, 2], [9, -6, -2, -1, 0, 5, -2, -1, 3, 4, -4, 2, 0, -3, -4, -2, -2], [-9, -4, -7, -2, -3, 3, 3, 2, 9, 5, 9, 2, 3, 0, -9, 4, 0], [-4, -7, 2, 3, -5, -2, 1, 1, 8, -3, 2, 4, 0, 3, 3, -1, -3], [3, 3, 10, 2, -6, -8, -1, -2, 3, -6, 4, 10, 3, 1, 4, -2, -6], [6, 9, 0, 2, 3, -2, 2, -7, 0, -6, -4, -3, -6, -4, 5, -8, 0], [-10, -3, 11, -4, 3, -3, 7, 0, -3, -9, -1, -1, 4, 1, 0, 1, 1], [-1, -3, 0, -5, 1, 2, 9, 5, 2, 3, -1, 7, 0, -1, 1, 11, 3], [-18, 4, 2, -1, 5, -2, 3, -3, 2, 0, 0, 3, -1, 2, 1, -1, 5], [0, 2, 0, -4, 5, 3, -1, 3, 1, -5, 7, -9, 2, -4, 2, 2, 7], [18, 6, 4, -2, 10, -6, 2, 1, -4, -5, -2, 4, 4, -4, 8, -5, -2], [6, 5, 3, 15, -1, 10, -12, -10, 0, 7, -2, 1, 3, 6, -6, -1, 0], [1, -2, -1, 2, -5, 4, -1, -4, -8, 3, 4, -3, -1, -3, 1, 1, 1], [-4, 7, 2, 3, 6, 1, -3, 0, -12, 3, -5, -8, -6, -1, 4, -3, 1], [-2, -20, -4, 0, -3, -5, 8, 6, 6, -2, -2, 4, 2, 2, -5, 5, -2], [25, 0, 1, 1, -6, 7, 0, 1, -6, 0, 4, -2, -1, 5, 3, 0, 7], [-7, 3, -5, 6, -8, 7, -10, -1, 6, 3, -2, 2, -1, 3, -7, 2, -7], [-2, -1, 0, 10, -3, 3, -7, -7, 8, 6, -1, 1, 1, 4, -1, -4, -4], [14, 4, -4, -5, 11, 1, 3, 0, 4, 2, 0, 5, -6, -3, 8, 2, 4], [5, -1, 3, -1, -1, -2, -1, -7, -6, -3, -1, 3, -6, -1, 8, 1, -7], [-7, 0, -6, -7, -3, -1, 5, 6, 3, 0, -3, 3, -1, 1, -1, 3, 6], [13, -12, -3, 4, 5, 11, -9, -4, -7, 3, -1, 4, -4, 10, -4, -6, 4], [7, -3, 4, 3, 11, 8, -1, -4, -7, 2, 7, -9, 2, -3, -2, -2, 12], [16, -3, 1, 0, 2, 1, -5, 2, 2, -1, 0, 0, 0, -1, -5, -4, -7], [-4, 4, 6, 5, 6, -1, -1, 1, 2, -5, -2, -4, 1, -5, 0, -7, -1], [21, 4, 10, 2, 2, -12, 10, 2, 0, -10, -1, 7, 2, 1, 3, -2, -2], [-2, -9, -10, -9, -10, -5, 3, 9, 10, 0, 9, -1, 1, 4, -1, 6, 7], [3, 4, 1, 2, 10, 3, -7, -9, -8, -5, -2, -2, 5, -5, 6, -1, 6], [0, 11, -3, -6, 4, -10, 7, 1, 3, -5, -6, 2, 0, -7, 1, 4, -2], [17, 6, 4, 0, 15, 1, 10, 1, -1, 2, 3, 1, -4, -2, 5, -5, 1], [0, 9, 3, 1, -7, -3, 3, 0, -1, 3, 5, -1, 3, -2, 2, -4, 2], [2, 12, 1, 5, 15, 2, 3, -6, -3, 1, 8, -5, -5, -9, 3, -11, 3], [-14, -3, 0, -1, 0, -8, 0, -3, 6, -4, 0, 4, 1, -9, 1, -2, -7], [-3, 3, 1, -8, 8, -3, 8, -1, -3, -5, 2, -2, -7, 2, 7, -2, 2], [8, 6, 5, 2, -2, 1, -2, -2, -5, -7, -2, -4, 0, 0, 6, 2, -2], [-10, 4, 0, -7, -3, 1, 13, 10, 5, -4, -8, 5, -7, -3, -3, 0, -5], [-8, -5, 16, 15, -5, 13, -18, -7, -8, 1, -2, -6, 11, 3, -11, 1, -2], [3, -1, 2, 0, -3, 0, 5, 1, 5, -3, 6, 5, -2, 6, 0, 5, 3], [2, -1, -4, 2, 5, -2, 3, 4, 6, 8, 6, -2, -8, -4, 3, -8, 1], [10, -9, 9, 1, 1, 1, -1, -9, -12, -6, 3, -1, 6, 3, 5, 2, -2], [8, 3, 7, 5, 17, 1, 3, -2, 0, 4, -4, 0, -5, -2, 5, -3, 4], [16, -12, -5, 2, 10, 8, -3, -9, -7, 3, -1, 3, 1, 2, -2, 1, 5], [8, 11, -11, 8, 13, 6, 1, 3, 7, 9, -3, -1, -3, 0, 1, -3, 7], [17, -10, 7, 2, -9, 6, -14, -5, -9, 1, -1, -1, 3, -1, -2, -4, -7], [4, 6, 3, 1, -9, -7, 5, 4, -4, -2, 3, -5, 1, 0, -2, 3, 2], [-19, -7, -4, 5, -15, -10, 0, 3, 3, -2, 0, 5, 7, 6, -4, 2, -8], [16, -8, 9, 4, 11, 4, -6, -8, -14, -5, -2, -2, 0, -2, 3, -13, -5], [-6, 5, 6, -2, 5, -3, 6, 4, 1, -2, -1, -5, 0, -1, 1, -2, 0], [-32, 13, 8, 1, -9, -6, -4, -6, -7, -11, 2, -7, 7, -10, 2, -1, 1], [-16, 4, -1, 0, -8, 2, -7, -4, -3, -5, 0, -8, 7, -6, -6, 2, -1], [8, 18, -4, -3, 7, -9, 8, 3, 7, 2, -8, 9, -4, 0, 5, -8, -10], [6, -7, 2, -2, -11, 4, 1, 5, -3, -7, -4, 5, -5, 2, 3, -4, 1], [6, 12, 4, -4, -1, -5, 3, 0, -15, -4, 1, -3, 1, -8, 3, -6, -4], [16, 6, 4, -2, 13, -10, 7, 3, -1, -6, 2, 1, 3, 0, 9, -7, -4], [-20, -11, -4, -4, -13, -3, -3, 2, 2, -3, 3, -5, 4, -3, -2, 3, 0], [0, 17, 6, 4, 0, -8, -5, -4, -13, -6, -7, -4, -5, -4, 8, -5, -5], [-16, -2, 3, -1, -15, 1, -1, 2, 0, -4, 0, -1, -2, -1, -4, -6, -6], [7, -13, 7, 7, -1, 6, -4, -1, -2, 2, 9, 0, 4, 1, -4, -1, 5], [18, -15, -2, 1, 2, 5, -13, -2, -3, 7, 8, -4, 4, 4, -1, 3, -1], [-9, 6, -7, 4, 0, -5, -6, 8, 17, 7, -8, -2, 0, -3, -2, -3, -4], [15, 12, 4, 1, 4, 4, -10, -12, -10, -4, -6, -6, -3, -10, 5, -7, 2], [-11, 18, -8, -10, 6, 5, 1, -2, 4, 3, -5, 1, -8, -5, 5, -1, 7], [-19, -7, 5, -1, -4, 4, -3, -6, -5, 2, 6, 0, 6, 4, 7, 5, 7], [-9, 8, -4, 3, 10, 0, 1, -4, -1, -3, 0, 2, -4, -2, 5, -14, 2], [9, 3, -10, -4, 12, -7, 2, 3, 3, 1, -1, -2, -8, -7, -2, -2, -1], [-4, -6, -1, 9, 4, 4, -12, -6, 1, 4, 6, -4, 6, -1, -3, 3, -2], [17, -2, 10, 5, 2, -4, 3, 0, 6, -3, -4, 6, 3, 4, 10, 2, 1], [-11, 8, 6, -4, -11, -7, 1, -2, -1, -6, -1, 7, -2, 5, 2, -6, -9], [-19, 0, 3, -1, -17, -5, 2, 4, -1, -6, 0, 2, 5, -6, -4, 0, -9], [-1, 11, -5, 6, -1, 3, -11, -6, -4, -5, -5, -7, 1, -4, -1, -9, -5], [0, -5, 4, -2, -10, -5, 1, 0, -9, -7, 4, -4, 4, 1, 9, 2, 2], [-8, 6, -13, -10, 10, -11, 25, 11, 7, -2, 0, 9, 1, 2, 4, 4, 2], [-23, 3, 0, 10, 0, 2, -5, -1, 9, 1, -1, -8, 8, -1, -11, -3, 3], [-11, -17, 6, 3, -6, 5, -2, -2, -1, -2, -1, 3, 9, 3, -6, 9, -1], [8, -18, -2, -5, -19, -3, -4, 6, -11, -1, 4, 1, 4, 3, -1, 6, -3], [11, 0, -13, 6, 17, 1, -9, 2, 11, 15, 3, -2, -5, 0, -5, -3, 5], [-3, 0, -4, -2, 5, 4, -1, 0, 12, 3, 4, 11, 0, 7, 0, -2, 6], [14, 8, 0, -1, 14, 1, 3, 2, 1, -4, -5, -6, 3, 0, 2, -6, 3], [9, -11, 5, 4, -3, 9, -18, -1, -7, 5, -2, 5, 3, 2, -4, -5, -10], [-2, 10, -3, -3, -2, -2, 4, 1, -1, -5, -9, 8, -3, 4, 3, 5, -4], [-6, -6, 9, -6, -4, 0, -11, -5, -9, -4, 6, -4, 3, -7, 0, -4, 0], [11, 5, -1, 6, 5, -5, -2, -6, -7, -2, -9, 0, -1, -2, 7, 0, 3], [5, 2, -1, 9, 10, -7, -6, -10, 2, 1, 6, -6, -1, -8, 7, -9, -3], [-14, -9, 3, -6, -9, -9, 8, 3, 1, -9, 11, -3, 5, 2, 2, 6, 3], [-9, -14, -6, -6, -18, -3, 0, 10, 0, -3, 6, -2, 1, -1, -6, 1, -5], [-6, -12, 2, -6, -13, 5, -12, -4, -8, -3, 9, -3, 8, 3, 1, 3, -2], [7, 3, 4, -2, -8, -5, 1, 3, -6, -2, -1, 8, 0, 1, 5, 4, -10], [-5, 8, 3, -4, -5, -10, 9, -1, 2, -10, -2, -3, 1, 2, 1, -3, -6], [-8, -6, -5, -8, -9, 5, -4, -2, -2, 3, -9, -1, -4, 1, -3, 3, 0], [27, 1, 1, -13, -4, -7, 16, 4, -1, -8, -4, -2, 2, -2, 4, 10, -1], [5, -16, 1, -4, -5, -6, 7, 7, 6, -5, 4, 10, -3, 7, -1, 8, -2], [11, 6, 7, -8, 2, 6, 2, -1, -6, -7, 8, -7, 2, 0, -3, 6, 8], [3, -6, -15, 5, 1, 8, 0, 10, 6, 10, -10, 1, -6, 8, -10, 1, 1], [17, -5, -5, 10, 10, 12, -10, -9, 2, 10, 6, -2, 3, 3, -7, 2, 8], [-8, -5, 8, 0, -8, -2, -7, -1, -6, -5, 7, 3, 13, -4, -5, 1, -9], [17, 1, -10, 6, 12, 2, 1, 2, -1, 2, 1, -2, -11, 4, 6, -8, 5], [-12, -1, -2, 8, -6, -3, -7, -5, -4, 0, -3, 4, -4, -1, 3, -7, -12], [-19, 1, -10, -3, 1, -7, 12, -1, 19, 2, 1, 6, 1, -1, 0, 6, 5], [15, 10, 1, -15, 4, -16, 23, 8, 2, -11, -2, 2, 0, -5, 5, -2, -5], [-34, -10, -7, 3, -2, 2, -5, 0, 3, 9, -2, -2, 3, 2, -6, 1, 2], [-8, 4, 13, 12, 6, -2, -19, -6, -2, 1, -5, -2, 0, -3, 7, -11, -6], [-7, 13, 6, -1, 10, 5, -11, -7, -2, 6, 9, -4, 1, -5, 8, -5, 9], [3, -2, -3, 3, 3, -2, -5, -1, -5, 2, 3, -6, 3, -5, -8, 1, -4], [23, 2, 6, -3, 5, -6, -3, 1, -7, -6, -7, 1, 1, -2, 5, -1, 4], [9, 6, 1, 9, 16, 4, -2, -7, 3, 3, -2, 2, -3, 2, 7, -8, 1], [17, -3, -2, -6, -3, -1, 10, 6, 1, 0, 1, 1, -2, 6, -1, 3, 6], [-2, -5, -10, 4, -11, 7, -12, -1, -2, 5, -4, -5, 4, 2, -5, 0, 3], [10, -7, -11, -5, -4, -6, 5, 5, 3, -3, -4, 8, 4, 5, 5, 11, 1], [11, -8, 12, -3, -15, 1, -6, -8, -7, 1, 3, -5, 1, 0, -3, 6, 1], [7, -5, -8, 1, 9, 5, -1, 7, 11, 10, 4, 3, -1, 4, -5, 8, 7], [-2, 2, -3, 7, 5, 1, -7, -3, -12, -5, 0, -5, 1, -4, -3, -8, 1], [3, 3, 9, 6, -11, 6, -11, -5, -3, 1, -5, -1, -1, 6, 5, -3, -2], [14, 1, -4, -1, 5, 1, 5, 2, -3, -3, -4, -1, -4, -5, 4, -13, -2], [-3, -10, 0, 9, 5, 9, -10, -3, 0, 12, -4, 1, -5, -6, -4, -4, -2], [-5, -5, 3, -3, 3, -2, 1, 4, -1, -2, 1, -9, 3, -3, 1, 9, 3], [19, -10, 13, 9, -5, 9, -18, -6, -18, 1, 2, -7, 3, 1, 0, -6, 5], [6, -8, -2, 2, 10, 0, 11, 3, 3, 2, -5, 2, -7, -1, 2, 5, 8], [6, -7, -5, 1, -12, -3, 4, 10, 7, 8, -1, 0, -1, 3, -7, 12, -3], [0, -5, 1, 7, 2, -2, -6, -1, 2, -2, 0, 0, 1, 8, 0, -1, 0], [28, -4, 11, -1, 5, 6, -5, -13, -12, -11, -4, -4, 2, -1, 6, -3, 2], [-15, 17, -2, 1, 7, -13, 12, 2, 0, -4, 7, 1, 5, -3, 6, -1, 5], [2, -10, 10, 7, -11, 0, -12, -9, -4, -1, -4, -1, 6, -3, 7, -2, -4], [-15, -9, 6, -1, -12, 4, -3, 5, 0, -3, -5, 2, 8, 2, -10, 4, 1], [3, 3, 0, 3, -2, 5, -13, -13, 7, 4, 5, 2, 0, -5, -1, 5, 0], [-9, 18, -3, -12, -6, -12, 16, 5, 8, -11, 1, 10, -1, 3, 5, 4, 1], [1, 6, 9, -1, -15, -2, 7, -1, 1, 2, 2, 3, -1, 2, 1, 6, -2], [4, 5, 0, 6, 6, -6, 4, 5, 10, 6, -7, 4, -8, -5, 6, -5, -3], [7, 4, 5, 3, 2, 0, 2, -9, -8, -5, -1, 10, 0, 7, -2, 0, -7], [-14, 7, -7, 8, 8, -5, 3, 0, 12, -3, -6, -2, -6, -9, 3, -7, -4], [16, 13, 10, 1, 11, -5, 2, -3, -12, -3, -4, 5, 1, 0, 8, -3, 0], [-5, 7, 10, 3, 13, 2, -3, -4, -22, -6, 2, -7, 7, 1, -1, 0, 2], [3, 6, -18, -13, -2, -9, 17, 16, 6, -4, -10, 8, -4, 4, 1, 6, 0], [18, -6, -5, -2, 14, 5, 8, 6, 6, 11, 9, 2, -3, -2, 1, 2, 4], [-7, 5, -10, -3, 9, 5, -2, 2, 1, 0, 5, -5, -4, -2, 5, -1, 10], [3, -2, -2, 0, 14, 3, 4, 1, 2, -6, 0, -2, 0, -3, 4, 1, 12], [-13, 4, 3, 7, -6, 8, -15, -14, -12, 1, 0, 3, -4, 3, 0, -7, -4], [-7, -7, 11, -6, -12, 0, -2, -7, -13, 1, 8, 7, 0, 2, 0, 2, -10], [-2, -10, 1, -7, -10, -1, 10, 7, 4, -6, 9, 3, -2, 12, -1, 10, 3], [-12, 5, 3, 5, 0, 8, -14, -8, -10, 5, 0, -10, 10, -4, -2, 0, 6], [-7, -13, 1, -3, 3, 2, -2, -4, -3, -1, -9, 3, -5, -5, 4, -5, -7], [16, 9, 1, -2, 5, 6, 2, 2, 11, 10, 5, 4, -10, -4, -1, -5, -5], [0, 4, 9, 6, -13, 6, -19, -10, -13, -3, 15, -3, 10, 7, -2, 2, -1], [6, -19, 2, 11, -9, 13, -12, -2, 2, 10, 0, 3, 10, 15, -11, 14, -2], [-7, 2, -5, -6, -9, -16, 18, 8, 7, -7, 0, 2, -1, 6, 2, 3, -3], [7, -5, -12, 2, 1, -7, -4, 4, 10, 4, 4, 2, -2, -6, 0, 3, 0], [-12, 5, -10, -7, -2, -11, 9, 12, 5, -3, -2, 0, 3, -2, 2, -1, -3], [2, 2, -4, 0, -11, 5, -7, 6, -2, 6, -5, 1, 1, 5, -9, 0, 1], [-4, -7, -1, 13, -8, 3, -13, -2, 5, 4, 9, 1, 6, 3, -1, -1, 3], [-27, 7, 0, 2, 4, 7, 2, -3, 8, 4, -1, 5, -2, 0, -8, -1, 0], [9, -14, -5, -5, -2, 3, 6, 6, 1, -3, -2, -2, 2, 1, -4, 3, 10], [10, 11, -4, 1, 4, -6, 3, -6, 0, 0, -5, 10, -8, 2, 3, -8, -5], [8, 7, 1, 6, 24, 13, -3, -8, 3, 5, 2, -7, -11, 1, -5, -14, 6], [19, 6, 10, 9, -7, -8, -10, -14, -11, -6, -5, -1, 1, -3, 4, -12, -12], [-18, -14, 10, 11, -15, 4, -15, -7, -6, -2, 12, -1, 4, 6, -2, 3, -9], [10, 16, 10, 3, 19, 5, -14, -16, -22, -9, -5, -5, 2, -12, 4, -18, -1], [11, 21, 5, 3, 9, -9, 0, -7, -5, -7, 4, -3, -1, -8, 4, -13, 2], [12, 17, 0, 0, 15, -5, 4, -6, -17, -12, -3, 1, 1, 1, 6, 0, 2], [-4, -22, 3, -6, -6, 8, -1, -3, -6, 4, 11, -4, 5, 7, -2, 7, 7], [17, -4, 5, 6, 0, 7, -14, -11, -13, 8, 1, -4, 1, 7, 5, -6, 5], [2, 24, -7, -7, 8, -3, 2, -3, -3, -5, -1, -7, 7, -4, 5, -4, 5], [-10, 3, 2, 4, -7, 0, -4, 0, 5, 1, 2, -3, 2, 5, 1, 2, -2], [-7, 10, 2, 3, 11, -5, -7, -11, 2, -3, -3, -5, 2, -8, 6, -4, -3], [14, -9, 1, -6, -14, 0, 4, 1, -8, 0, 5, -2, 8, 7, -6, 11, 3], [-20, 1, -1, -6, 0, -7, 18, 12, 7, -2, 1, 0, 8, 4, -2, 5, 4], [19, 4, -3, 2, 7, 4, 9, 1, 7, 8, -5, 7, -7, 5, 0, 2, 5], [9, -26, -1, -9, -13, -2, 21, 16, 8, -6, 2, 6, 3, 4, -1, 14, 7], [11, -4, 4, 9, -3, 2, -2, 5, -2, 1, 5, -3, -2, 8, 5, -1, 1], [12, -11, -12, -1, -5, 3, 7, 2, -4, 1, -5, -1, -7, 9, -1, 7, 4], [6, 0, -7, 1, -1, 12, -4, 0, -1, 4, 7, -8, -2, 2, -2, 7, 14], [-11, -4, -3, -1, -18, 0, 4, 10, 11, 12, 10, 8, -6, 3, -2, 2, -4], [-1, 14, 3, 6, -8, -2, 2, 3, -6, -1, -6, 6, -1, 11, 3, -1, -7], [-20, 17, -3, -2, -3, -5, -2, -6, -4, -2, -1, 1, -2, -15, 11, -8, -5], [-25, -11, 2, 1, -18, -2, -7, -1, -4, -6, 3, -3, 5, 2, -4, -4, -4], [18, -4, 2, -2, 4, -8, -6, -4, -4, -10, -3, 4, 1, 4, 5, -12, -5], [-1, 8, -8, 8, 8, -3, 3, 2, 11, 0, 4, 2, -3, 0, -2, -10, 3], [-3, -5, -2, 11, 9, 7, -11, -4, -9, 3, -2, -9, 1, -7, -7, -4, -8], [7, -4, -15, -5, -6, 6, 2, 12, 7, 8, 8, 6, -7, 8, -5, 5, -1], [-3, 15, -13, -7, 23, -4, 14, 7, 7, 4, -5, 1, -12, -8, -3, -2, 1], [-2, 17, -2, -3, 3, -12, 8, -7, -8, -14, -6, 7, -7, -8, 10, -9, -9], [13, 13, -12, 0, 15, -5, 13, 13, 5, 4, -10, 3, -14, 2, 4, -10, -5]]
